
// ******************************************************************
// Copyright (c) 2003 Satoshi, All Rights Reserved.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Author : Satoshi ( af230533@yahoo.co.jp )
// ******************************************************************

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qwhatsthis.h>
#include <qtextcodec.h>	// v1.0.0
#include <qlabel.h>

#include "jump.h"


JumpDialog::JumpDialog( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	int       xx;
	bool	c700 = false;
	QTextCodec	*codec;

	// ---------------------------------- frame size
	xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	// ----------------------------------- v1.0.0 Japanese name
	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "ֹ楸" ) );

	QLabel* label1 = new QLabel( codec->toUnicode( "ֹ" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 5, 10, 60, 30 ) );
	else
		label1->setGeometry( QRect( 5, 10, 40, 20 ) );

	LineEdit1 = new QLineEdit( this );
	if ( c700 )
		LineEdit1->setGeometry( QRect( 70, 10, 90, 30 ) );
	else
		LineEdit1->setGeometry( QRect( 50, 10, 60, 20 ) );
	LineEdit1->setMaxLength ( 5 );

	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 2, 50, 36, 26 ) );
	else
		PushButton1->setGeometry( QRect( 2, 40, 24, 18 ) );
	PushButton1->setText( codec->toUnicode( "OK" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 76, 50, 84, 26 ) );
	else
		PushButton2->setGeometry( QRect( 56, 40, 56, 26 ) );
	PushButton2->setText( codec->toUnicode( "ݎ" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( jumpSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );
	connect( LineEdit1 ,SIGNAL( returnPressed()), this, SLOT( inputNumber()));
}


void JumpDialog::accept()
{
	bool	ok;
	int	len;

	codec = QTextCodec::codecForName( "eucJP" );
	QString	num_all = codec->toUnicode( "" );

	num = LineEdit1->text();
	len = num.length();
	for( int i= 0 ; i < len ; i++ )
	{
		int index = num_all.find( num[i] );
		if ( index >= 0 )
			num[i] = '0' + index;
	}

	num.toUInt( &ok );
	if ( ok )
		QDialog::accept();
	else
		LineEdit1->setFocus();
}

void JumpDialog::jumpSelected()
{
	accept();
}

void JumpDialog::inputNumber()
{
	PushButton1->setFocus();
}


void JumpDialog::setOldStr( QString str )
{
	if (( str ) && ( str.length() > 0 ))
		LineEdit1->setText( str );
		LineEdit1->selectAll();			// v3.2.3
}



/*
 *  Destroys the object and frees any allocated resources
 */
JumpDialog::~JumpDialog()
{
    // no need to delete child widgets, Qt does it all for us
}


// --------------------------------------------------------------
// Confirm dialog of Replace
// --------------------------------------------------------------

ConfirmDialog::ConfirmDialog( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;

	// ----------------------------------- v1.0.0 Japanese name
	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "ִǧ" ) );

	QLabel* label1 = new QLabel( codec->toUnicode( "֤ޤ" ), this );
	label1->setGeometry( QRect( 5, 5, 160, 30 ) );

	PushButton1 = new QPushButton( this, "PushButton1" );
	PushButton1->setGeometry( QRect( 2, 40, 36, 26 ) );
	PushButton1->setText( codec->toUnicode( "OK" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	PushButton2->setGeometry( QRect( 40, 40, 36, 26 ) );
	PushButton2->setText( codec->toUnicode( "No" ) );

	PushButton3 = new QPushButton( this, "PushButton3" );
	PushButton3->setGeometry( QRect( 78, 40, 84, 26 ) );
	PushButton3->setText( codec->toUnicode( "ݎ" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( okSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( noSelected()) );
	connect( PushButton3 ,SIGNAL( clicked()), this, SLOT( cancelSelected()) );
	selected = true;
}


void ConfirmDialog::accept()
{
	QDialog::accept();
}

void ConfirmDialog::okSelected()
{
	selected = true;
	accept();
}


void ConfirmDialog::noSelected()
{
	selected = false;
	accept();
}


void ConfirmDialog::cancelSelected()
{
	selected = -1;
	accept();
}


/*
 *  Destroys the object and frees any allocated resources
 */
ConfirmDialog::~ConfirmDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

