
// ******************************************************************
// Copyright (c) 2003 Satoshi, All Rights Reserved.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Author : Satoshi ( af230533@yahoo.co.jp )
// ******************************************************************

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qwhatsthis.h>
#include <qtextcodec.h>	// v1.0.0
#include <qlabel.h>
#include <qcombobox.h>
#include <qcheckbox.h>
#include <qaccel.h>		// v2.1.3
#include <qfontdatabase.h>

#include "zeditor.h"
#include "optdialog.h"

//static const char* item1[] = { "ʤ", "" };
static const char* item1[] = { "No", "Yes" };
static const char* item2[] = { "", "", "", "", "", "", "", "" };
static const char* item3[] = { "", "ǻ", "ǻ", "ǻ", "", "", "ǻ", "", "", "", "", "", "", "", "", "", "", "", ""  };
static const char* item4[] = { "", "", "", "", "", "", "", "" };
static const char* item5[] = { "", "ǻ", "", "", "", "ǻ", "", "" };
static const char* item6[] = { "", "", "", "", "", "", "" };
static const char* item7[] = { "ʤ", "10ʬ", "ꤷʸ", "åץܡɤ" };
static const char* item8[] = { "YYYY/MM/DD() hh:mm:ss",
                               "YYYY/MM/DD() hh:mm",
                               "YYYY/MM/DD()",
                               "YYYY/MM/DD hh:mm:ss",
                               "YYYY/MM/DD hh:mm",
                               "YYYY/MM/DD",
                               "YYYY.MM.DD hh:mm:ss",
                               "YYYY.MM.DD hh:mm",
                               "YYYY.MM.DD",
                               "hh:mm:ss YYYY/MM/DD",
                               "hh:mm YYYY/MM/DD",
                               "week month DD YYYY",
                               "" };
static const char* item9[] = { "(1", "(2", "(3", "(4", "(5", "", "", "", "" };
static const char* item10[] = { "Σ", "ľ", "", "", "ʣ" };
static const char* item11[] = { "", "ǻ", "ǻ", "ǻ", "", "ǻ", "" };
static const char* item12[] = { "No", "Ď", "Ƭ2", "Ƭ3", "Ƭ4" };
static const char* item13[] = { "ư", "", "99", "" };
static const char* item14[] = { "No", "", "", "", "" };
static const char* item15[] = { "ư", "UTF-8", "S-JIS", "eucJP", "JIS7", "eucKR", "GBK" };
static const char* item16[] = { "No", "", "", "", "", "", "", "", "ǻ", "ǻ", "ǻ", "ǻ", "ǻ"  };
static const char* item17[] = { "No", "10", "15", "20", "25", "30", "35", "40" };
static const char* item18[] = { "̤ʤ+̾", "̤ʤ+", "̤+̾", "̤+"  };
static const char* item19[] = { "ξɽ", "ʿΤ", "ľΤ", "ξʤ" };
static const char* item20[] = { "No", "No", "No", "No", "No" };

static const char* item21[] = { "ʤ", "Ⱦѥڡ", "ʸư", "Redo", "Undo", "Ժ", "ʣ", "", "򸡺", "ִ", "դȻ", "Ѷ", "Ύ̎٤Υѥ", "٤", "򸡺", "¸", "̾դ¸", "ʸѴ" };

static const char* item22[] = { "No", "Win", "Mac" };
static const char* item23[] = { "", "" };



// *******************************************************************
// Dialog : showing option
// *******************************************************************

OptionDialog::OptionDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;
	bool		c700 = false;

	int xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	// ----------------------------------- v1.0.0 Japanese name
	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "[ɽ]ץ" ) );

	QLabel* label1 = new QLabel( codec->toUnicode( "硼ȥåȥɽ" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 2, 3, 240, 25 ) );
	else
		label1->setGeometry( QRect( 2, 3, 160, 17 ) );
	ComboBox1 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1->setGeometry( QRect( 250, 0, 90, 30 ) );
	else
		ComboBox1->setGeometry( QRect( 166, 0, 60, 20 ) );


	QLabel* label2 = new QLabel( codec->toUnicode( "طʤο" ), this );
	if ( c700 )
		label2->setGeometry( QRect( 2, 35, 180, 25 ) );
	else
		label2->setGeometry( QRect( 2, 23, 120, 17 ) );
	ComboBox2 = new QComboBox( false, this );
	if ( c700 )
		ComboBox2->setGeometry( QRect( 250, 32, 90, 30 ) );
	else
		ComboBox2->setGeometry( QRect( 166, 21, 60, 20 ) );


	QLabel* label3 = new QLabel( codec->toUnicode( "ʸο" ), this );
	if ( c700 )
		label3->setGeometry( QRect( 2, 67, 180, 25 ) );
	else
		label3->setGeometry( QRect( 2, 43, 120, 17 ) );
	ComboBox3 = new QComboBox( false, this );
	if ( c700 )
		ComboBox3->setGeometry( QRect( 250, 62, 90, 34 ) );
	else
		ComboBox3->setGeometry( QRect( 166, 41, 60, 20 ) );



	QLabel* label4 = new QLabel( codec->toUnicode( "饤" ), this );
	if ( c700 )
		label4->setGeometry( QRect( 2, 99, 156, 25 ) );
	else
		label4->setGeometry( QRect( 2, 63, 103, 17 ) );
	ComboBox4 = new QComboBox( false, this );
	if ( c700 )
		ComboBox4->setGeometry( QRect( 158, 96, 90, 30 ) );
	else
		ComboBox4->setGeometry( QRect( 105, 61, 60, 20 ) );

	ComboBox5 = new QComboBox( false, this );
	if ( c700 )
		ComboBox5->setGeometry( QRect( 250,  96, 90, 30 ) );
	else
		ComboBox5->setGeometry( QRect( 166,  61, 60, 20 ) );



	QLabel* label6 = new QLabel( codec->toUnicode( "" ), this );
	if ( c700 )
		label6->setGeometry( QRect( 2, 132, 156, 25 ) );
	else
		label6->setGeometry( QRect( 2,  86, 103, 17 ) );
	ComboBox6 = new QComboBox( false, this );
	if ( c700 )
		ComboBox6->setGeometry( QRect( 158, 127, 90, 34 ) );
	else
		ComboBox6->setGeometry( QRect( 105,  83, 60, 20 ) );

	ComboBox7 = new QComboBox( false, this );
	if ( c700 )
		ComboBox7->setGeometry( QRect( 250, 127, 90, 34 ) );
	else
		ComboBox7->setGeometry( QRect( 166,  83, 60, 20 ) );



	QLabel* label8 = new QLabel( codec->toUnicode( ",Tab¾ޡɽ" ), this );
	if ( c700 )
		label8->setGeometry( QRect( 2, 161, 240, 25 ) );
	else
		label8->setGeometry( QRect( 2, 103, 160, 17 ) );
	ComboBox8 = new QComboBox( false, this );
	if ( c700 )
		ComboBox8->setGeometry( QRect( 250, 158, 90, 30 ) );
	else
		ComboBox8->setGeometry( QRect( 166, 101, 60, 20 ) );


	QLabel* label9 = new QLabel( codec->toUnicode( "ֹɽ" ), this );
	if ( c700 )
		label9->setGeometry( QRect( 2, 193, 160, 25 ) );
	else
		label9->setGeometry( QRect( 2, 123, 107, 17 ) );

	ComboBox10 = new QComboBox( false, this );
	if ( c700 )
		ComboBox10->setGeometry( QRect( 150, 188, 90, 34 ) );
	else
		ComboBox10->setGeometry( QRect( 102, 121, 60, 20 ) );

	ComboBox9 = new QComboBox( false, this );
	if ( c700 )
		ComboBox9->setGeometry( QRect( 240, 188, 100, 34 ) );
	else
		ComboBox9->setGeometry( QRect( 162, 121, 64, 20 ) );



	QLabel* label11 = new QLabel( codec->toUnicode( "򤵤줿ϰϤο" ), this );
	if ( c700 )
		label11->setGeometry( QRect( 2, 225, 180, 25 ) );
	else
		label11->setGeometry( QRect( 2, 143, 120, 17 ) );
	ComboBox11 = new QComboBox( false, this );
	if ( c700 )
		ComboBox11->setGeometry( QRect( 250, 222, 90, 30 ) );
	else
		ComboBox11->setGeometry( QRect( 166, 141, 60, 20 ) );


	QLabel* label12 = new QLabel( codec->toUnicode( "Сƥ饤" ), this );
	if ( c700 )
		label12->setGeometry( QRect( 2, 257, 180, 25 ) );
	else
		label12->setGeometry( QRect( 2, 163, 120, 17 ) );
	ComboBox12 = new QComboBox( false, this );
	if ( c700 )
		ComboBox12->setGeometry( QRect( 250, 254, 90, 30 ) );
	else
		ComboBox12->setGeometry( QRect( 166, 161, 60, 20 ) );


	QLabel* label13 = new QLabel( codec->toUnicode( "Сɽ" ), this );
	if ( c700 )
		label13->setGeometry( QRect( 2, 291, 180, 25 ) );
	else
		label13->setGeometry( QRect( 2, 183, 120, 17 ) );
	ComboBox13 = new QComboBox( false, this );
	if ( c700 )
		ComboBox13->setGeometry( QRect( 200, 286, 140, 34 ) );
	else
		ComboBox13->setGeometry( QRect( 132, 181, 94, 20 ) );

	// --------------------------------------------- v3.1.0
	QLabel* label14 = new QLabel( codec->toUnicode( "ʸե" ), this );
	if ( c700 )
		label14->setGeometry( QRect( 2, 325, 160, 25 ) );
	else
		label14->setGeometry( QRect( 2, 203, 107, 17 ) );

	ComboBox14 = new QComboBox( false, this );
	if ( c700 )
		ComboBox14->setGeometry( QRect( 150, 320, 190, 34 ) );
	else
		ComboBox14->setGeometry( QRect( 102, 201, 124, 20 ) );

/*--------------------------------
	QLabel* label13 = new QLabel( codec->toUnicode( "" ), this );
	if ( c700 )
		label13->setGeometry( QRect( 2, 321, 180, 25 ) );
	else
		label13->setGeometry( QRect( 2, 203, 120, 17 ) );
	ComboBox13 = new QComboBox( false, this );
	if ( c700 )
		ComboBox13->setGeometry( QRect( 250, 318, 90, 30 ) );
	else
		ComboBox13->setGeometry( QRect( 166, 201, 60, 20 ) );
---------------------------------*/


	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 10, 356, 72, 26 ) );
	else
		PushButton1->setGeometry( QRect( 10, 223, 48, 18 ) );
	PushButton1->setText( codec->toUnicode( "ϣ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 220, 356, 110, 26 ) );
	else
		PushButton2->setGeometry( QRect( 142, 223,  74, 18 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( optionSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );

	int	i;
	for( i= 0 ; i < 2 ; i++ )
		ComboBox1->insertItem( codec->toUnicode( item1[i] ), i );

	for( i= 0 ; i < 8 ; i++ )
		ComboBox2->insertItem( codec->toUnicode( item2[i] ), i );

	for( i= 0 ; i < 19 ; i++ )
		ComboBox3->insertItem( codec->toUnicode( item3[i] ), i );

	for( i= 0 ; i < 5 ; i++ )
		ComboBox4->insertItem( codec->toUnicode( item10[i] ), i );

	for( i= 0 ; i < 8 ; i++ )
		ComboBox5->insertItem( codec->toUnicode( item5[i] ), i );

	for( i= 0 ; i < 9 ; i++ )
		ComboBox6->insertItem( codec->toUnicode( item9[i] ), i );

	for( i= 0 ; i < 8 ; i++ )
		ComboBox7->insertItem( codec->toUnicode( item4[i] ), i );

	for( i= 0 ; i < 5 ; i++ )
		ComboBox8->insertItem( codec->toUnicode( item14[i] ), i );

	for( i= 0 ; i < 5 ; i++ )
		ComboBox9->insertItem( codec->toUnicode( item12[i] ), i );

	for( i= 0 ; i < 2 ; i++ )
		ComboBox10->insertItem( codec->toUnicode( item23[i] ), i );

	for( i= 0 ; i < 7 ; i++ )
		ComboBox11->insertItem( codec->toUnicode( item11[i] ), i );

	for( i= 0 ; i < 8 ; i++ )
		ComboBox12->insertItem( codec->toUnicode( item17[i] ), i );

	for( i= 0 ; i < 4 ; i++ )
		ComboBox13->insertItem( codec->toUnicode( item19[i] ), i );

	// ---------------------------- v3.1.0
	QFontDatabase	*font_db = new QFontDatabase();
	ComboBox14->insertStringList( font_db->families() );

}


void OptionDialog::accept()
{
	QDialog::accept();
}

void OptionDialog::optionSelected()
{
	accept();
}


void OptionDialog::setShortCutKey( bool flg )
{
	ComboBox1->setCurrentItem( flg );
}

void OptionDialog::setBackgroundColor( int num )
{
	if (( num < 0 ) || ( num > 7 ))
		num = 0;
	ComboBox2->setCurrentItem( num );
}

void OptionDialog::setTextColor( int num )
{
	if (( num < 0 ) || ( num > 18 ))
		num = 0;
	ComboBox3->setCurrentItem( num );
}

void OptionDialog::setCursorLine( int num )
{
	if (( num < 0 ) || ( num > 4 ))
		num = 0;
	ComboBox4->setCurrentItem( num );
}

void OptionDialog::setCursorLineColor( int num )
{
	if (( num < 1 ) || ( num > 8 ))
		num = 1;
	num--;
	ComboBox5->setCurrentItem( num );
}

void OptionDialog::setCursorStyle( int width )
{
	if (( width < 1 ) || ( width > 9 ))
		width = 2;
	width--;
	ComboBox6->setCurrentItem( width );
}

void OptionDialog::setCursorColor( int num )
{
	if (( num < 0 ) || ( num > 7 ))
		num = 0;
	ComboBox7->setCurrentItem( num );
}

void OptionDialog::setCRMarkDisp( int num )
{
	ComboBox8->setCurrentItem( num );
}

void OptionDialog::setLineNumber( int num, bool cr_num )
{
	ComboBox9->setCurrentItem( num );
	ComboBox10->setCurrentItem( cr_num );
}

void OptionDialog::setSelectedColor( int num )
{
	if (( num < 0 ) || ( num > 6 ))
		num = 0;
	ComboBox11->setCurrentItem( num );
}

void OptionDialog::setVerticalLine( int num )
{
	if (( num < 0 ) || ( num > 7 ))
		num = 0;
	ComboBox12->setCurrentItem( num );
}

void OptionDialog::setScrollBarDisp( int num )
{
	if (( num < 0 ) || ( num > 3 ))
		num = 0;
	ComboBox13->setCurrentItem( num );
}

// -------------------------------- Font v3.1.0
void OptionDialog::setFontName( QString family_name )
{
	for( int i = 0 ; i < ComboBox14->count() ; i++ )
	{
		// check same name font
		if ( ( ComboBox14->text( i ) ) == family_name )
		{
			ComboBox14->setCurrentItem( i );
			break;
		}
	}
}






bool OptionDialog::getShortCutKey()
{
	return( ComboBox1->currentItem() );
}
int  OptionDialog::getBackgroundColor()
{
	return( ComboBox2->currentItem() );
}
int  OptionDialog::getTextColor()
{
	return( ComboBox3->currentItem() );
}
int OptionDialog::getCursorLine()
{
	return( ComboBox4->currentItem() );
}
int  OptionDialog::getCursorLineColor()
{
	int num = ComboBox5->currentItem();
	num++;
	return( num );
}
int  OptionDialog::getCursorWidth()
{
	int width = ComboBox6->currentItem();
	width++;
	return( width );
}
int  OptionDialog::getCursorColor()
{
	int num = ComboBox7->currentItem();
	return( num );
}
int  OptionDialog::getCRMarkDisp()
{
	int num = ComboBox8->currentItem();
	return( num );
}
int OptionDialog::getLineNumber()
{
	return( ComboBox9->currentItem() );
}
bool OptionDialog::getLineNumberCr()
{
	return( ComboBox10->currentItem() );
}
int  OptionDialog::getSelectedColor()
{
	int num = ComboBox11->currentItem();
	return( num );
}
int  OptionDialog::getVerticalLine()
{
	int num = ComboBox12->currentItem();
	return( num );
}
int  OptionDialog::getScrollBarDisp()
{
	int num = ComboBox13->currentItem();
	return( num );
}


QString  OptionDialog::getFontName()
{
	return( ComboBox14->currentText() );
}


/*
 *  Destroys the object and frees any allocated resources
 */
OptionDialog::~OptionDialog()
{
    // no need to delete child widgets, Qt does it all for us
}







// *******************************************************************
// Dialog : working option
// *******************************************************************

OptionDialog2::OptionDialog2( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;
	bool		c700 = false;

	int xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	// ----------------------------------- v1.0.0 Japanese name
	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "[ư]ץ" ) );

	QLabel* label1 = new QLabel( codec->toUnicode( "[]ư" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 2, 3, 180, 25 ) );
	else
		label1->setGeometry( QRect( 2, 3, 120, 17 ) );
	ComboBox1 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1->setGeometry( QRect( 210, 0, 90, 30 ) );
	else
		ComboBox1->setGeometry( QRect( 140, 0, 60, 20 ) );

/*--------
	QLabel* label2 = new QLabel( codec->toUnicode( "룲ʬ" ), this );
	if ( c700 )
		label2->setGeometry( QRect( 2, 35, 180, 25 ) );
	else
		label2->setGeometry( QRect( 2, 23, 120, 17 ) );
	ComboBox2 = new QComboBox( false, this );
	if ( c700 )
		ComboBox2->setGeometry( QRect( 182, 32, 90, 30 ) );
	else
		ComboBox2->setGeometry( QRect( 122, 21, 60, 20 ) );
------*/

	QLabel* label3 = new QLabel( codec->toUnicode( "̎JISԎĎղ" ), this );
	if ( c700 )
		label3->setGeometry( QRect( 2, 35, 180, 25 ) );
	else
		label3->setGeometry( QRect( 2, 23, 120, 17 ) );
	ComboBox3 = new QComboBox( false, this );
	if ( c700 )
		ComboBox3->setGeometry( QRect( 210, 32, 90, 30 ) );
	else
		ComboBox3->setGeometry( QRect( 140, 21, 60, 20 ) );


	QLabel* label4 = new QLabel( codec->toUnicode( "ִ" ), this );
//	QLabel* label4 = new QLabel( codec->toUnicode( "ʸʸ" ), this );
	if ( c700 )
		label4->setGeometry( QRect( 2, 67, 90, 25 ) );
	else
		label4->setGeometry( QRect( 2, 43, 60, 17 ) );
	ComboBox4 = new QComboBox( false, this );
	if ( c700 )
		ComboBox4->setGeometry( QRect( 120, 62, 180, 34 ) );
	else
		ComboBox4->setGeometry( QRect( 80, 41, 120, 20 ) );


	QLabel* label5 = new QLabel( codec->toUnicode( "ݎ؎Ҏݎَλ" ), this );
	if ( c700 )
		label5->setGeometry( QRect( 2, 99, 180, 25 ) );
	else
		label5->setGeometry( QRect( 2, 63, 120, 17 ) );
	ComboBox5 = new QComboBox( false, this );
	if ( c700 )
		ComboBox5->setGeometry( QRect( 210, 96, 90, 30 ) );
	else
		ComboBox5->setGeometry( QRect( 140, 61, 60, 20 ) );


	QLabel* label6 = new QLabel( codec->toUnicode( "֤ˡȥ" ), this );
	if ( c700 )
		label6->setGeometry( QRect( 2, 131, 180, 25 ) );
	else
		label6->setGeometry( QRect( 2,  83, 120, 17 ) );
	ComboBox6 = new QComboBox( true, this );
	if ( c700 )
		ComboBox6->setGeometry( QRect( 210, 126, 90, 34 ) );
	else
		ComboBox6->setGeometry( QRect( 140, 81, 60, 20 ) );


	QLabel* label7 = new QLabel( codec->toUnicode( "ԣΥ" ), this );
	if ( c700 )
		label7->setGeometry( QRect( 2, 163, 180, 25 ) );
	else
		label7->setGeometry( QRect( 2, 103, 120, 17 ) );
	ComboBox7 = new QComboBox( false, this );
	if ( c700 )
		ComboBox7->setGeometry( QRect( 210, 160, 90, 30 ) );
	else
		ComboBox7->setGeometry( QRect( 140, 101, 60, 20 ) );


	QLabel* label8 = new QLabel( codec->toUnicode( "ώ̎٤ʸĎ" ), this );
	if ( c700 )
		label8->setGeometry( QRect( 2, 195, 180, 25 ) );
	else
		label8->setGeometry( QRect( 2, 123, 120, 17 ) );
	ComboBox8 = new QComboBox( false, this );
	if ( c700 )
		ComboBox8->setGeometry( QRect( 190, 190, 110, 34 ) );
	else
		ComboBox8->setGeometry( QRect( 127, 121, 73, 20 ) );


	QLabel* label9 = new QLabel( codec->toUnicode( "ώ̎٤ʸĎ" ), this );
	if ( c700 )
		label9->setGeometry( QRect( 2, 225, 180, 25 ) );
	else
		label9->setGeometry( QRect( 2, 143, 120, 17 ) );
	ComboBox9 = new QComboBox( false, this );
	if ( c700 )
		ComboBox9->setGeometry( QRect( 190, 222, 110, 34 ) );
	else
		ComboBox9->setGeometry( QRect( 127, 141, 73, 20 ) );


	QLabel* label10 = new QLabel( codec->toUnicode( "ʸư(,ִ)" ), this );
	if ( c700 )
		label10->setGeometry( QRect( 2, 255, 250, 25 ) );
	else
		label10->setGeometry( QRect( 2, 163, 166, 17 ) );
	ComboBox10 = new QComboBox( false, this );
	if ( c700 )
		ComboBox10->setGeometry( QRect( 28, 282, 272, 30 ) );
	else
		ComboBox10->setGeometry( QRect( 18, 182, 182, 20 ) );


	QLabel* label11 = new QLabel( codec->toUnicode( "դȻ֤Υե" ), this );
	if ( c700 )
		label11->setGeometry( QRect( 2, 315, 260, 25 ) );
	else
		label11->setGeometry( QRect( 2, 204, 174, 17 ) );
	ComboBox11 = new QComboBox( false, this );
	if ( c700 )
		ComboBox11->setGeometry( QRect( 28, 342, 272, 30 ) );
	else
		ComboBox11->setGeometry( QRect( 18, 223, 182, 20 ) );


	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 10, 374, 72, 26 ) );
	else
		PushButton1->setGeometry( QRect( 10, 245, 48, 18 ) );
	PushButton1->setText( codec->toUnicode( "ϣ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 168, 374, 110, 26 ) );
	else
		PushButton2->setGeometry( QRect( 108, 245,  74, 18 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( optionSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );

	int	i;
	for( i= 0 ; i < 2 ; i++ )
	{
		ComboBox1->insertItem( codec->toUnicode( item1[i] ), i );
		ComboBox5->insertItem( codec->toUnicode( item1[i] ), i );
	}

	// ------------------------------------ v2.2.2 append Macintosh CR code
	for( i= 0 ; i < 3 ; i++ )
		ComboBox3->insertItem( codec->toUnicode( item22[i] ), i );

	for( i= 0 ; i < 4 ; i++ )
		ComboBox4->insertItem( codec->toUnicode( item18[i] ), i );

	for( i= 0 ; i < 4 ; i++ )
		ComboBox6->insertItem( codec->toUnicode( item13[i] ), i );
	ComboBox6->setInsertionPolicy( QComboBox::NoInsertion );


	for( i= 0 ; i < 7 ; i++ )
		ComboBox7->insertItem( codec->toUnicode( item6[i] ), i );

	for( i= 0 ; i < 7 ; i++ )
	{
		ComboBox8->insertItem( codec->toUnicode( item15[i] ), i );
		ComboBox9->insertItem( codec->toUnicode( item15[i] ), i );
	}

	for( i= 0 ; i < 4 ; i++ )
		ComboBox10->insertItem( codec->toUnicode( item7[i] ), i );
	for( i= 0 ; i < 12 ; i++ )
		ComboBox11->insertItem( codec->toUnicode( item8[i] ), i );
}


void OptionDialog2::accept()
{
	QDialog::accept();
}

void OptionDialog2::optionSelected()
{
	accept();
}


void OptionDialog2::setMoveCursor( bool flg )
{
	ComboBox1->setCurrentItem( flg );
}

void OptionDialog2::setAppendCRCode( int flg )
{
	ComboBox3->setCurrentItem( flg );
}

void OptionDialog2::setCaseSensitive( int flg )
{
	ComboBox4->setCurrentItem( flg );
}

void OptionDialog2::setIncrementalSearch( bool flg )
{
	ComboBox5->setCurrentItem( flg );
}

void OptionDialog2::setWordWrap( int flg_col )
{
	if ( flg_col > 3 )
	{
		QString		s;
		ComboBox6->changeItem( s.arg( flg_col ), 2 );
		flg_col = 2;
	}
	ComboBox6->setCurrentItem( flg_col );
}

void OptionDialog2::setTabLength( int num )
{
	
	if (( num < 2 ) || ( num > 8 ))
		num = 8;
	num -= 2;
	ComboBox7->setCurrentItem( num );
}

void OptionDialog2::setInputCodec( int num )
{
	if (( num < 0 ) || ( num > 7 ))
		num = 0;
	ComboBox8->setCurrentItem( num );
}

void OptionDialog2::setOutputCodec( int num )
{
	if (( num < 0 ) || ( num > 7 ))
		num = 0;
	ComboBox9->setCurrentItem( num );
}

void OptionDialog2::setCursorWord( int num )
{
	if (( num < 0 ) || ( num > 3 ))
		num = 0;
	ComboBox10->setCurrentItem( num );
}

void OptionDialog2::setDateForm( int num )
{
	if ( num == 19 )
		num = 11;
	ComboBox11->setCurrentItem( num );
}



bool OptionDialog2::getMoveCursor()
{
	return( ComboBox1->currentItem() );
}
int OptionDialog2::getAppendCRCode()
{
	return( ComboBox3->currentItem() );
}

bool OptionDialog2::getCaseSensitive()
{
	return( ComboBox4->currentItem() );
}

bool OptionDialog2::getIncrementalSearch()
{
	return( ComboBox5->currentItem() );
}

int OptionDialog2::getWordWrap()
{
	int	index = ComboBox6->currentItem();
	if ( index == 2 )
	{
		QString	num = ComboBox6->currentText();
		int col = num.toInt();
		if (( col < 10 ) || ( col > 200 ))
			col = 0;
		return( col );
	}
	return( index );
}

int  OptionDialog2::getTabLength()
{
	int num = ComboBox7->currentItem();
	num += 2;
	return( num );
}

int  OptionDialog2::getInputCodec()
{
	int num = ComboBox8->currentItem();
	return( num );
}

int  OptionDialog2::getOutputCodec()
{
	int num = ComboBox9->currentItem();
	return( num );
}

int  OptionDialog2::getCursorWord()
{
	return( ComboBox10->currentItem() );
}
int  OptionDialog2::getDateForm()
{
	int num = ComboBox11->currentItem();
	if ( num == 11 )
		num = 19;
	return( num );
}


/*
 *  Destroys the object and frees any allocated resources
 */
OptionDialog2::~OptionDialog2()
{
    // no need to delete child widgets, Qt does it all for us
}






// *******************************************************************
// Dialog 3 : reserved word option
// *******************************************************************

OptionDialog3::OptionDialog3( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;
	bool		c700 = false;

	int xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "[ʬ]ץ" ) );

	// ----------------------------------- v2.1.1
	RegexCheckBox = new QCheckBox( this );
	if ( c700 )
		RegexCheckBox->setGeometry( QRect( 2, 0, 338, 25 ) );
	else
		RegexCheckBox->setGeometry( QRect( 2, 0, 224, 17 ) );
	RegexCheckBox->setText( codec->toUnicode( "[ʬ]ɽȤ" ) );

	QPalette p = RegexCheckBox->palette();
	p.setColor( QColorGroup::Background, Qt::cyan );
	RegexCheckBox->setPalette( p );
//	RegexCheckBox->update();




	// ----------------------------------- v1.2.5 1byte char
	QLabel* label1 = new QLabel( codec->toUnicode( "ƥȎ̎   Ⱦʸ" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 2, 28, 238, 25 ) );
	else
		label1->setGeometry( QRect( 2, 20, 158, 17 ) );
	ComboBox1 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1->setGeometry( QRect( 250, 25, 90, 33 ) );
	else
		ComboBox1->setGeometry( QRect( 166, 17, 60, 22 ) );


	QLabel* label1_1 = new QLabel( codec->toUnicode( "1" ), this );
	if ( c700 )
		label1_1->setGeometry( QRect( 20, 61, 30, 25 ) );
	else
		label1_1->setGeometry( QRect( 20, 42, 21, 17 ) );

	LineEdit1rsv1 = new QLineEdit( this );
	if ( c700 )
		LineEdit1rsv1->setGeometry( QRect( 50, 58, 200, 33 ) );
	else
		LineEdit1rsv1->setGeometry( QRect( 41, 39, 125, 22 ) );

	ComboBox1_1 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1_1->setGeometry( QRect( 250, 58, 90, 33 ) );
	else
		ComboBox1_1->setGeometry( QRect( 166, 39, 60, 22 ) );


	QLabel* label1_2 = new QLabel( codec->toUnicode( "2" ), this );
	if ( c700 )
		label1_2->setGeometry( QRect( 20, 94, 30, 25 ) );
	else
		label1_2->setGeometry( QRect( 20, 64, 21, 17 ) );

	LineEdit2rsv1 = new QLineEdit( this );
	if ( c700 )
		LineEdit2rsv1->setGeometry( QRect( 50, 91, 200, 33 ) );
	else
		LineEdit2rsv1->setGeometry( QRect( 41, 61, 125, 22 ) );

	ComboBox1_2 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1_2->setGeometry( QRect( 250, 91, 90, 33 ) );
	else
		ComboBox1_2->setGeometry( QRect( 166, 61, 60, 22 ) );


	QLabel* label1_3 = new QLabel( codec->toUnicode( "3" ), this );
	if ( c700 )
		label1_3->setGeometry( QRect( 20, 127, 30, 25 ) );
	else
		label1_3->setGeometry( QRect( 20, 86, 21, 17 ) );

	LineEdit3rsv1 = new QLineEdit( this );
	if ( c700 )
		LineEdit3rsv1->setGeometry( QRect( 50, 124, 200, 33 ) );
	else
		LineEdit3rsv1->setGeometry( QRect( 41, 83, 125, 22 ) );

	ComboBox1_3 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1_3->setGeometry( QRect( 250, 124, 90, 33 ) );
	else
		ComboBox1_3->setGeometry( QRect( 166, 83, 60, 22 ) );


	LineEdit1comm = new QLineEdit( this );
	if ( c700 )
		LineEdit1comm->setGeometry( QRect( 20, 157, 60, 34 ) );
	else
		LineEdit1comm->setGeometry( QRect( 20, 105, 40, 22 ) );

	QLabel* label1comm = new QLabel( codec->toUnicode( "ޤǤο" ), this );
	if ( c700 )
		label1comm->setGeometry( QRect( 82, 160, 160, 25 ) );
	else
		label1comm->setGeometry( QRect( 62, 108, 107, 17 ) );

	ComboBox1comm = new QComboBox( false, this );
	if ( c700 )
		ComboBox1comm->setGeometry( QRect( 250, 157, 90, 34 ) );
	else
		ComboBox1comm->setGeometry( QRect( 166, 105, 60, 22 ) );






	QLabel* label2 = new QLabel( codec->toUnicode( "桼ե" ), this );
	if ( c700 )
		label2->setGeometry( QRect( 2, 193, 228, 25 ) );
	else
		label2->setGeometry( QRect( 2, 129, 148, 17 ) );

	// ------------------------------------------ user number v2.1.3
	ComboBox2_0 = new QComboBox( false, this );
	if ( c700 )
		ComboBox2_0->setGeometry( QRect( 250, 191, 90, 33 ) );
	else
		ComboBox2_0->setGeometry( QRect( 166, 127, 60, 22 ) );


	QLabel* label2_1 = new QLabel( codec->toUnicode( "ĥ" ), this );
	if ( c700 )
		label2_1->setGeometry( QRect( 20, 221, 60, 25 ) );
	else
		label2_1->setGeometry( QRect( 20, 149, 40, 17 ) );

	LineEdit1rsv2 = new QLineEdit( this );
	if ( c700 )
		LineEdit1rsv2->setGeometry( QRect( 80, 218, 170, 33 ) );
	else
		LineEdit1rsv2->setGeometry( QRect( 60, 146, 106, 22 ) );


	QLabel* label2_2 = new QLabel( codec->toUnicode( "1" ), this );
	if ( c700 )
		label2_2->setGeometry( QRect( 20, 254, 30, 25 ) );
	else
		label2_2->setGeometry( QRect( 20, 171, 21, 17 ) );

	LineEdit2rsv2 = new QLineEdit( this );
	if ( c700 )
		LineEdit2rsv2->setGeometry( QRect( 50, 251, 200, 33 ) );
	else
		LineEdit2rsv2->setGeometry( QRect( 41, 168, 125, 22 ) );

	ComboBox2 = new QComboBox( false, this );
	if ( c700 )
		ComboBox2->setGeometry( QRect( 250, 251, 90, 33 ) );
	else
		ComboBox2->setGeometry( QRect( 166, 168, 60, 22 ) );


	QLabel* label2_3 = new QLabel( codec->toUnicode( "2" ), this );
	if ( c700 )
		label2_3->setGeometry( QRect( 20, 287, 30, 25 ) );
	else
		label2_3->setGeometry( QRect( 20, 193, 21, 17 ) );

	LineEdit3rsv2 = new QLineEdit( this );
	if ( c700 )
		LineEdit3rsv2->setGeometry( QRect( 50, 284, 200, 33 ) );
	else
		LineEdit3rsv2->setGeometry( QRect( 41, 190, 125, 22 ) );

	ComboBox3 = new QComboBox( false, this );
	if ( c700 )
		ComboBox3->setGeometry( QRect( 250, 284, 90, 33 ) );
	else
		ComboBox3->setGeometry( QRect( 166, 190, 60, 22 ) );


	QLabel* label2_4 = new QLabel( codec->toUnicode( "3" ), this );
	if ( c700 )
		label2_4->setGeometry( QRect( 20, 320, 30, 25 ) );
	else
		label2_4->setGeometry( QRect( 20, 215, 21, 17 ) );

	LineEdit4rsv2 = new QLineEdit( this );
	if ( c700 )
		LineEdit4rsv2->setGeometry( QRect( 50, 317, 200, 33 ) );
	else
		LineEdit4rsv2->setGeometry( QRect( 41, 212, 125, 22 ) );

	ComboBox4 = new QComboBox( false, this );
	if ( c700 )
		ComboBox4->setGeometry( QRect( 250, 317, 90, 33 ) );
	else
		ComboBox4->setGeometry( QRect( 166, 212, 60, 22 ) );


	LineEdit2comm = new QLineEdit( this );
	if ( c700 )
		LineEdit2comm->setGeometry( QRect( 20, 350, 60, 33 ) );
	else
		LineEdit2comm->setGeometry( QRect( 20, 234, 40, 22 ) );

	QLabel* label2comm = new QLabel( codec->toUnicode( "ޤǤο" ), this );
	if ( c700 )
		label2comm->setGeometry( QRect( 82, 353, 160, 25 ) );
	else
		label2comm->setGeometry( QRect( 62, 237, 107, 17 ) );

	ComboBox2comm = new QComboBox( false, this );
	if ( c700 )
		ComboBox2comm->setGeometry( QRect( 250, 350, 90, 33 ) );
	else
		ComboBox2comm->setGeometry( QRect( 166, 234, 60, 22 ) );



	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 10, 383, 72, 26 ) );
	else
		PushButton1->setGeometry( QRect( 10, 256, 48, 18 ) );
	PushButton1->setText( codec->toUnicode( "ϣ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 220, 383, 110, 26 ) );
	else
		PushButton2->setGeometry( QRect( 142, 256,  74, 18 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( optionSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );

	int	i;
	for( i= 0 ; i < 13 ; i++ )
	{
		ComboBox1->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox1_1->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox1_2->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox1_3->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox2->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox3->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox4->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox1comm->insertItem( codec->toUnicode( item16[i] ), i );
		ComboBox2comm->insertItem( codec->toUnicode( item16[i] ), i );
	}
	// --------------------------- user number
	for( i= 0 ; i < FILE_ETC - 1 ; i++ )
		ComboBox2_0->insertItem( codec->toUnicode( item20[i] ), i );
	connect( ComboBox2_0 ,SIGNAL( activated(int)), this, SLOT( changedUserNum(int)) );
	now_user = FILE_USER1;

	QAccel	*acc_key = new QAccel( this );
	acc_key->connectItem( acc_key->insertItem( Key_U + CTRL ), this, SLOT( changeUserUp()) );
	acc_key->connectItem( acc_key->insertItem( Key_Up + CTRL ), this, SLOT( changeUserUp()) );
	acc_key->connectItem( acc_key->insertItem( Key_PageUp ), this, SLOT( changeUserUp()) );
	acc_key->connectItem( acc_key->insertItem( Key_Down + CTRL ), this, SLOT( changeUserDown()) );
	acc_key->connectItem( acc_key->insertItem( Key_PageDown ), this, SLOT( changeUserDown()) );
}


void OptionDialog3::accept()
{
	QDialog::accept();
}

void OptionDialog3::optionSelected()
{
	accept();
}

void OptionDialog3::changeUserUp()
{
	int		index;

	index = now_user + 1;
	if ( index > FILE_USER5 )
		index = FILE_USER1;
	ComboBox2_0->setCurrentItem( index - 1 );
	changedUserNum2( index );
}

void OptionDialog3::changeUserDown()
{
	int		index;

	index = now_user - 1;
	if ( index < FILE_USER1 )
		index = FILE_USER5;
	ComboBox2_0->setCurrentItem( index - 1 );
	changedUserNum2( index );
}

// --------------------------------------------- v3.5.1 bug fix
void OptionDialog3::changedUserNum( int index )
{
	changedUserNum2( index + 1 );
}

void OptionDialog3::changedUserNum2( int index )
{
	int		k;
	int		ii;
	QString	r_txt;

	k = now_user;
	ii = index;
	now_user = index;

	r_txt = LineEdit1rsv2->text();
	user[k].Ext   = changeSpace( r_txt );
	r_txt = LineEdit2rsv2->text();
	user[k].Word1 = changeSpace( r_txt );
	r_txt = LineEdit3rsv2->text();
	user[k].Word2 = changeSpace( r_txt );
	r_txt = LineEdit4rsv2->text();
	user[k].Word3 = changeSpace( r_txt );
	r_txt = LineEdit2comm->text();
	user[k].Comment = changeSpace( r_txt );

	user[k].Color1 = ComboBox2->currentItem();
	user[k].Color2 = ComboBox3->currentItem();
	user[k].Color3 = ComboBox4->currentItem();
	user[k].CommentColor = ComboBox2comm->currentItem();

	LineEdit1rsv2->setText( user[ii].Ext );
	LineEdit2rsv2->setText( user[ii].Word1 );
	LineEdit3rsv2->setText( user[ii].Word2 );
	LineEdit4rsv2->setText( user[ii].Word3 );
	LineEdit2comm->setText( user[ii].Comment );
	ComboBox2->setCurrentItem( user[ii].Color1 );
	ComboBox3->setCurrentItem( user[ii].Color2 );
	ComboBox4->setCurrentItem( user[ii].Color3 );
	ComboBox2comm->setCurrentItem( user[ii].CommentColor );
}

// -----------------------------------------------------


void OptionDialog3::setWhichRegExpress( bool which )
{
	RegexCheckBox->setChecked( which );
}


void OptionDialog3::setTextCharDispColor( int num )		// half char color
{
	if (( num < 0 ) || ( num > 12 ))
		num = 0;
	ComboBox1->setCurrentItem( num );
}

void OptionDialog3::setTextReservedWord( QString str )
{
	LineEdit1rsv1->setText( str );
}

void OptionDialog3::setTextReservedWord2( QString str )
{
	LineEdit2rsv1->setText( str );
}

void OptionDialog3::setTextReservedWord3( QString str )
{
	LineEdit3rsv1->setText( str );
}

void OptionDialog3::setTextReservedColor( int num )
{
	if (( num < 0 ) || ( num > 12 ))
		num = 0;
	ComboBox1_1->setCurrentItem( num );
}

void OptionDialog3::setTextReservedColor2( int num )
{
	if (( num < 0 ) || ( num > 12 ))
		num = 0;
	ComboBox1_2->setCurrentItem( num );
}

void OptionDialog3::setTextReservedColor3( int num )
{
	if (( num < 0 ) || ( num > 12 ))
		num = 0;
	ComboBox1_3->setCurrentItem( num );
}

void OptionDialog3::setTextCommentWord( QString str )
{
	LineEdit1comm->setText( str );
}

void OptionDialog3::setTextCommentColor( int num )
{
	if (( num < 0 ) || ( num > 12 ))
		num = 0;
	ComboBox1comm->setCurrentItem( num );
}

// -----------------------------------------------------

void OptionDialog3::setUserReserved( int index, UserFileInfo one_user )
{
	user[index] = one_user;
}


void OptionDialog3::setUserReservedShow( int file_type )
{
	int		index;

	if (( file_type == FILE_TEXT ) || ( file_type == FILE_ETC ))
		index = FILE_USER1;
	else
		index = file_type;

	now_user = index;
	ComboBox2_0->setCurrentItem( index - 1 );
	LineEdit1rsv2->setText( user[index].Ext );
	LineEdit2rsv2->setText( user[index].Word1 );
	LineEdit3rsv2->setText( user[index].Word2 );
	LineEdit4rsv2->setText( user[index].Word3 );
	ComboBox2->setCurrentItem( user[index].Color1 );
	ComboBox3->setCurrentItem( user[index].Color2 );
	ComboBox4->setCurrentItem( user[index].Color3 );
	LineEdit2comm->setText( user[index].Comment );
	ComboBox2comm->setCurrentItem( user[index].CommentColor );
}

// -----------------------------------------------------

QString  OptionDialog3::changeSpace( QString str )
{
	QTextCodec	*codec;
	// ---------------------------------------- from 2byte space to 1byte space
	codec = QTextCodec::codecForName( "eucJP" );
	QString	z_spc = codec->toUnicode( "" );

	int	len = str.length();
	for( int i = 0 ; i < len ;  i++ )
	{
		if ( str[i] == z_spc[0] )
			str[i] = ' ';
	}
	return( str );
}



UserFileInfo  OptionDialog3::getTextInfo()
{
	QString		r_txt;

	user[0].RegExpress = RegexCheckBox->isChecked();
	user[0].half_color = ComboBox1->currentItem();

	r_txt = LineEdit1rsv1->text();
	user[0].Word1   = changeSpace( r_txt );
	r_txt = LineEdit2rsv1->text();
	user[0].Word2   = changeSpace( r_txt );
	r_txt = LineEdit3rsv1->text();
	user[0].Word3   = changeSpace( r_txt );
	r_txt = LineEdit1comm->text();
	user[0].Comment = changeSpace( r_txt );

	user[0].Color1 = ComboBox1_1->currentItem();
	user[0].Color2 = ComboBox1_2->currentItem();
	user[0].Color3 = ComboBox1_3->currentItem();
	user[0].CommentColor = ComboBox1comm->currentItem();
	return( user[0] );
}


// -----------------------------------------------------

UserFileInfo  OptionDialog3::getUserInfo( int which )
{
	int			i;
	QString		r_txt;

	i = which;			// FILE_USER1 or FILE_USER2
	if ( now_user == which )
	{
		r_txt = LineEdit1rsv2->text();
		user[i].Ext   = changeSpace( r_txt );

		r_txt = LineEdit2rsv2->text();
		user[i].Word1 = changeSpace( r_txt );

		r_txt = LineEdit3rsv2->text();
		user[i].Word2 = changeSpace( r_txt );

		r_txt = LineEdit4rsv2->text();
		user[i].Word3 = changeSpace( r_txt );

		r_txt = LineEdit2comm->text();
		user[i].Comment = changeSpace( r_txt );

		user[i].Color1 = ComboBox2->currentItem();
		user[i].Color2 = ComboBox3->currentItem();
		user[i].Color3 = ComboBox4->currentItem();
		user[i].CommentColor = ComboBox2comm->currentItem();
	}
	return( user[i] );
}


/*
 *  Destroys the object and frees any allocated resources
 */
OptionDialog3::~OptionDialog3()
{
    // no need to delete child widgets, Qt does it all for us
}





// *******************************************************************
// Dialog : idiom option
// *******************************************************************

OptionDialog4::OptionDialog4( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;
	bool		c700 = false;

	int xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "[Ѷ]ץ" ) );

	// ----------------------------------- v2.1.0 editfield of idiom
	QLabel* label1 = new QLabel( codec->toUnicode( "1" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 2, 3, 10, 25 ) );
	else
		label1->setGeometry( QRect( 2, 3,  7, 17 ) );
	LineEdit1 = new QLineEdit( this );
	if ( c700 )
		LineEdit1->setGeometry( QRect( 14, 0, 326, 34 ) );
	else
		LineEdit1->setGeometry( QRect( 10, 0, 216, 22 ) );

	QLabel* label2 = new QLabel( codec->toUnicode( "2" ), this );
	if ( c700 )
		label2->setGeometry( QRect( 2, 36, 10, 25 ) );
	else
		label2->setGeometry( QRect( 2, 24,  7, 17 ) );
	LineEdit2 = new QLineEdit( this );
	if ( c700 )
		LineEdit2->setGeometry( QRect( 14, 36, 326, 34 ) );
	else
		LineEdit2->setGeometry( QRect( 10, 24, 216, 22 ) );

	QLabel* label3 = new QLabel( codec->toUnicode( "3" ), this );
	if ( c700 )
		label3->setGeometry( QRect( 2, 72, 10, 25 ) );
	else
		label3->setGeometry( QRect( 2, 48,  7, 17 ) );
	LineEdit3 = new QLineEdit( this );
	if ( c700 )
		LineEdit3->setGeometry( QRect( 14, 72, 326, 34 ) );
	else
		LineEdit3->setGeometry( QRect( 10, 48, 216, 22 ) );

	QLabel* label4 = new QLabel( codec->toUnicode( "4" ), this );
	if ( c700 )
		label4->setGeometry( QRect( 2, 108, 10, 25 ) );
	else
		label4->setGeometry( QRect( 2,  72,  7, 17 ) );
	LineEdit4 = new QLineEdit( this );
	if ( c700 )
		LineEdit4->setGeometry( QRect( 14, 108, 326, 34 ) );
	else
		LineEdit4->setGeometry( QRect( 10,  72, 216, 22 ) );

	QLabel* label5 = new QLabel( codec->toUnicode( "5" ), this );
	if ( c700 )
		label5->setGeometry( QRect( 2, 144, 10, 25 ) );
	else
		label5->setGeometry( QRect( 2,  96,  7, 17 ) );
	LineEdit5 = new QLineEdit( this );
	if ( c700 )
		LineEdit5->setGeometry( QRect( 14, 144, 326, 34 ) );
	else
		LineEdit5->setGeometry( QRect( 10,  96, 216, 22 ) );

	QLabel* label6 = new QLabel( codec->toUnicode( "6" ), this );
	if ( c700 )
		label6->setGeometry( QRect( 2, 180, 10, 25 ) );
	else
		label6->setGeometry( QRect( 2, 120,  7, 17 ) );
	LineEdit6 = new QLineEdit( this );
	if ( c700 )
		LineEdit6->setGeometry( QRect( 14, 180, 326, 34 ) );
	else
		LineEdit6->setGeometry( QRect( 10, 120, 216, 22 ) );

	QLabel* label7 = new QLabel( codec->toUnicode( "7" ), this );
	if ( c700 )
		label7->setGeometry( QRect( 2, 216, 10, 25 ) );
	else
		label7->setGeometry( QRect( 2, 144,  7, 17 ) );
	LineEdit7 = new QLineEdit( this );
	if ( c700 )
		LineEdit7->setGeometry( QRect( 14, 216, 326, 34 ) );
	else
		LineEdit7->setGeometry( QRect( 10, 144, 216, 22 ) );

	QLabel* label8 = new QLabel( codec->toUnicode( "8" ), this );
	if ( c700 )
		label8->setGeometry( QRect( 2, 252, 10, 25 ) );
	else
		label8->setGeometry( QRect( 2, 168,  7, 17 ) );
	LineEdit8 = new QLineEdit( this );
	if ( c700 )
		LineEdit8->setGeometry( QRect( 14, 252, 326, 34 ) );
	else
		LineEdit8->setGeometry( QRect( 10, 168, 216, 22 ) );

	QLabel* label9 = new QLabel( codec->toUnicode( "9" ), this );
	if ( c700 )
		label9->setGeometry( QRect( 2, 288, 10, 25 ) );
	else
		label9->setGeometry( QRect( 2, 192,  7, 17 ) );
	LineEdit9 = new QLineEdit( this );
	if ( c700 )
		LineEdit9->setGeometry( QRect( 14, 288, 326, 34 ) );
	else
		LineEdit9->setGeometry( QRect( 10, 192, 216, 22 ) );



	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 10, 324, 72, 26 ) );
	else
		PushButton1->setGeometry( QRect( 10, 216, 48, 18 ) );
	PushButton1->setText( codec->toUnicode( "ϣ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 220, 324, 110, 26 ) );
	else
		PushButton2->setGeometry( QRect( 142, 216,  74, 18 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( optionSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );
}


void OptionDialog4::accept()
{
	QDialog::accept();
}

void OptionDialog4::optionSelected()
{
	accept();
}

// -----------------------------------------------------

void OptionDialog4::setThisIdiom( int index, QString str )
{
	QLineEdit 	*LineEdit;
	switch( index )
	{
		case 0 :
				LineEdit = LineEdit1;
				break;
		case 1 :
				LineEdit = LineEdit2;
				break;
		case 2 :
				LineEdit = LineEdit3;
				break;
		case 3 :
				LineEdit = LineEdit4;
				break;
		case 4 :
				LineEdit = LineEdit5;
				break;
		case 5 :
				LineEdit = LineEdit6;
				break;
		case 6 :
				LineEdit = LineEdit7;
				break;
		case 7 :
				LineEdit = LineEdit8;
				break;
		default :
				LineEdit = LineEdit9;
				break;
	}
	LineEdit->setText( str );
}



// -----------------------------------------------------

QString  OptionDialog4::getThisIdiom( int index )
{
	QLineEdit 	*LineEdit;
	switch( index )
	{
		case 0 :
				LineEdit = LineEdit1;
				break;
		case 1 :
				LineEdit = LineEdit2;
				break;
		case 2 :
				LineEdit = LineEdit3;
				break;
		case 3 :
				LineEdit = LineEdit4;
				break;
		case 4 :
				LineEdit = LineEdit5;
				break;
		case 5 :
				LineEdit = LineEdit6;
				break;
		case 6 :
				LineEdit = LineEdit7;
				break;
		case 7 :
				LineEdit = LineEdit8;
				break;
		default :
				LineEdit = LineEdit9;
				break;
	}
	return( LineEdit->text() );
}


/*
 *  Destroys the object and frees any allocated resources
 */
OptionDialog4::~OptionDialog4()
{
    // no need to delete child widgets, Qt does it all for us
}





// *******************************************************************
// Dialog : special key option
// *******************************************************************

OptionDialog5::OptionDialog5( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	QTextCodec	*codec;
	bool		c700 = false;

	int xx = parent->width();
	if ( xx > 400 )			// check A300, B500 : 240 x 320 size is 2/3
		c700 = true;

	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "[ü쥭]ץ" ) );

	// -------------------------------------------------------------------
	QLabel* label1 = new QLabel( codec->toUnicode( "Ctrl  + Enter" ), this );
	if ( c700 )
		label1->setGeometry( QRect( 2, 5, 140, 25 ) );
	else
		label1->setGeometry( QRect( 2, 3, 94, 17 ) );
	ComboBox1 = new QComboBox( false, this );
	if ( c700 )
		ComboBox1->setGeometry( QRect( 146, 1, 194, 34 ) );
	else
		ComboBox1->setGeometry( QRect( 98, 1, 128, 22 ) );

	QLabel* label2 = new QLabel( codec->toUnicode( "Ctrl  + Space" ), this );
	if ( c700 )
		label2->setGeometry( QRect( 2, 39, 140, 25 ) );
	else
		label2->setGeometry( QRect( 2, 26, 94, 17 ) );
	ComboBox2 = new QComboBox( false, this );
	if ( c700 )
		ComboBox2->setGeometry( QRect( 146, 35, 194, 34 ) );
	else
		ComboBox2->setGeometry( QRect( 98, 24, 128, 22 ) );


	// -------------------------------------------------------------------
	QLabel* label3 = new QLabel( codec->toUnicode( "Shift + Enter" ), this );
	if ( c700 )
		label3->setGeometry( QRect( 2, 73, 140, 25 ) );
	else
		label3->setGeometry( QRect( 2, 49, 94, 17 ) );
	ComboBox3 = new QComboBox( false, this );
	if ( c700 )
		ComboBox3->setGeometry( QRect( 146, 69, 194, 34 ) );
	else
		ComboBox3->setGeometry( QRect( 98, 47, 128, 22 ) );

	QLabel* label4 = new QLabel( codec->toUnicode( "Shift + Space" ), this );
	if ( c700 )
		label4->setGeometry( QRect( 2, 107, 140, 25 ) );
	else
		label4->setGeometry( QRect( 2,  72, 94, 17 ) );
	ComboBox4 = new QComboBox( false, this );
	if ( c700 )
		ComboBox4->setGeometry( QRect( 146, 103, 194, 34 ) );
	else
		ComboBox4->setGeometry( QRect( 98,  70, 128, 22 ) );

	// -------------------------------------------------------------------
	QLabel* label5 = new QLabel( codec->toUnicode( "Fn    + M" ), this );
	if ( c700 )
		label5->setGeometry( QRect( 2, 141, 140, 25 ) );
	else
		label5->setGeometry( QRect( 2,  95, 94, 17 ) );
	ComboBox5 = new QComboBox( false, this );
	if ( c700 )
		ComboBox5->setGeometry( QRect( 146, 137, 194, 34 ) );
	else
		ComboBox5->setGeometry( QRect( 98,  93, 128, 22 ) );

	QLabel* label6 = new QLabel( codec->toUnicode( "Fn    + N" ), this );
	if ( c700 )
		label6->setGeometry( QRect( 2, 175, 140, 25 ) );
	else
		label6->setGeometry( QRect( 2, 118, 94, 17 ) );
	ComboBox6 = new QComboBox( false, this );
	if ( c700 )
		ComboBox6->setGeometry( QRect( 146, 171, 194, 34 ) );
	else
		ComboBox6->setGeometry( QRect( 98, 116, 128, 22 ) );

	// -------------------------------------------------------------------
	QLabel* label7 = new QLabel( codec->toUnicode( "Fn    + O" ), this );
	if ( c700 )
		label7->setGeometry( QRect( 2, 209, 140, 25 ) );
	else
		label7->setGeometry( QRect( 2, 141, 94, 17 ) );
	ComboBox7 = new QComboBox( false, this );
	if ( c700 )
		ComboBox7->setGeometry( QRect( 146, 205, 194, 34 ) );
	else
		ComboBox7->setGeometry( QRect( 98, 139, 128, 22 ) );

	QLabel* label8 = new QLabel( codec->toUnicode( "Fn    + P" ), this );
	if ( c700 )
		label8->setGeometry( QRect( 2, 243, 140, 25 ) );
	else
		label8->setGeometry( QRect( 2, 164, 94, 17 ) );
	ComboBox8 = new QComboBox( false, this );
	if ( c700 )
		ComboBox8->setGeometry( QRect( 146, 239, 194, 34 ) );
	else
		ComboBox8->setGeometry( QRect( 98, 162, 128, 22 ) );

	// -------------------------------------------------------------------
	QLabel* label9 = new QLabel( codec->toUnicode( "Fn    + A" ), this );
	if ( c700 )
		label9->setGeometry( QRect( 2, 277, 140, 25 ) );
	else
		label9->setGeometry( QRect( 2, 187, 94, 17 ) );
	ComboBox9 = new QComboBox( false, this );
	if ( c700 )
		ComboBox9->setGeometry( QRect( 146, 273, 194, 34 ) );
	else
		ComboBox9->setGeometry( QRect( 98, 185, 128, 22 ) );

	QLabel* label10 = new QLabel( codec->toUnicode( "Fn    + S" ), this );
	if ( c700 )
		label10->setGeometry( QRect( 2, 311, 140, 25 ) );
	else
		label10->setGeometry( QRect( 2, 210, 94, 17 ) );
	ComboBox10 = new QComboBox( false, this );
	if ( c700 )
		ComboBox10->setGeometry( QRect( 146, 307, 194, 34 ) );
	else
		ComboBox10->setGeometry( QRect( 98, 208, 128, 22 ) );



	PushButton1 = new QPushButton( this, "PushButton1" );
	if ( c700 )
		PushButton1->setGeometry( QRect( 10, 342, 72, 26 ) );
	else
		PushButton1->setGeometry( QRect( 10, 231, 48, 18 ) );
	PushButton1->setText( codec->toUnicode( "ϣ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	if ( c700 )
		PushButton2->setGeometry( QRect( 220, 342, 110, 26 ) );
	else
		PushButton2->setGeometry( QRect( 256, 231,  74, 18 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( optionSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );



	// --------------------------- user number
	for( int i= 0 ; i <= SP_CONVERT ; i++ )
	{
		ComboBox1->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox2->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox3->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox4->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox5->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox6->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox7->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox8->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox9->insertItem( codec->toUnicode( item21[i] ), i );
		ComboBox10->insertItem( codec->toUnicode( item21[i] ), i );
	}
}


void OptionDialog5::accept()
{
	QDialog::accept();
}

void OptionDialog5::optionSelected()
{
	accept();
}

// -----------------------------------------------------

void OptionDialog5::setSpecialKey( SpecialKey sp )
{
	ComboBox1->setCurrentItem( sp.ctrl_enter );
	ComboBox2->setCurrentItem( sp.ctrl_space );
	ComboBox3->setCurrentItem( sp.shift_enter );
	ComboBox4->setCurrentItem( sp.shift_space );
	ComboBox5->setCurrentItem( sp.fn_M );
	ComboBox6->setCurrentItem( sp.fn_N );
	ComboBox7->setCurrentItem( sp.fn_O );
	ComboBox8->setCurrentItem( sp.fn_P );
	ComboBox9->setCurrentItem( sp.fn_A );
	ComboBox10->setCurrentItem( sp.fn_S );
}



// -----------------------------------------------------

SpecialKey  OptionDialog5::getSpecialKey( void )
{
	d_sp.ctrl_enter  = ComboBox1->currentItem();
	d_sp.ctrl_space  = ComboBox2->currentItem();
	d_sp.shift_enter = ComboBox3->currentItem();
	d_sp.shift_space = ComboBox4->currentItem();
	d_sp.fn_M        = ComboBox5->currentItem();
	d_sp.fn_N        = ComboBox6->currentItem();
	d_sp.fn_O        = ComboBox7->currentItem();
	d_sp.fn_P        = ComboBox8->currentItem();
	d_sp.fn_A        = ComboBox9->currentItem();
	d_sp.fn_S        = ComboBox10->currentItem();
	return( d_sp );
}


/*
 *  Destroys the object and frees any allocated resources
 */
OptionDialog5::~OptionDialog5()
{
    // no need to delete child widgets, Qt does it all for us
}
