
// ******************************************************************
// Copyright (c) 2003 Satoshi, All Rights Reserved.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Author : Satoshi ( af230533@yahoo.co.jp )
// ******************************************************************

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qwhatsthis.h>
#include <qtextcodec.h>	// v1.0.0
#include <qlabel.h>
#include <qcheckbox.h>

#include "repdialog.h"


ReplaceDialog::ReplaceDialog( QWidget* parent,  const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
	int       xx, yy;
	QTextCodec	*codec;

	if ( ! name )
	{
		setName( "ReplaceDialog" );
	}

	// ---------------------------------- frame size
	// ---------------------------------- frame size
	xx = parent->width();
//	yy = parent->height();
	if ( xx < 408 )			// 240 x 320
		xx = 204;
	else					// 480x640, 640x480
		xx = 300;
	yy = 195;

	// ----------------------------------- v1.0.0 Japanese name
	codec = QTextCodec::codecForName( "eucJP" );

	setCaption( codec->toUnicode( "** ִ **" ) );

	QLabel* label1 = new QLabel( codec->toUnicode( "ʸ" ), this );
	label1->setGeometry( QRect( 5, 10, 90, 25 ) );

	LineEdit1 = new QLineEdit( this );
	LineEdit1->setGeometry( QRect( 5, 40, xx - 11, 25 ) );

	QLabel* label2 = new QLabel( codec->toUnicode( "ʸ" ), this );
	label2->setGeometry( QRect( 5, 70, 90, 25 ) );

	LineEdit2 = new QLineEdit( this );
	LineEdit2->setGeometry( QRect( 5, 100, xx - 11, 25 ) );

	FromCheckBox = new QCheckBox( this, "FromCheckBox" );
	FromCheckBox->setGeometry( QRect( 8, 135, xx - 11, 25 ) );
	FromCheckBox->setText( codec->toUnicode( "ִ֤" ) );

	EachCheckBox = new QCheckBox( this, "EachCheckBox" );
	EachCheckBox->setGeometry( QRect( 8, 165, xx - 11, 25 ) );
	EachCheckBox->setText( codec->toUnicode( "ִǧ" ) );

	PushButton1 = new QPushButton( this, "PushButton1" );
	PushButton1->setGeometry( QRect( 8, 195, 72, 26 ) );
	PushButton1->setText( codec->toUnicode( "ִ" ) );

	PushButton2 = new QPushButton( this, "PushButton2" );
	PushButton2->setGeometry( QRect( xx - 115, 195, 110, 26 ) );
	PushButton2->setText( codec->toUnicode( "󥻥" ) );

	connect( PushButton1 ,SIGNAL( clicked()), this, SLOT( replaceSelected()) );
	connect( PushButton2 ,SIGNAL( clicked()), this, SLOT( hide()) );
	connect( LineEdit1 ,SIGNAL( returnPressed()), this, SLOT( inputOldStr()));
	connect( LineEdit2 ,SIGNAL( returnPressed()), this, SLOT( inputNewStr()));
}


void ReplaceDialog::accept()
{
	old_str = LineEdit1->text();
	new_str = LineEdit2->text();
	which_from = FromCheckBox->isChecked();
	which_each = EachCheckBox->isChecked();
	if ( LineEdit1->text().length() > 0 )
		QDialog::accept();
	else
		LineEdit1->setFocus();
}

void ReplaceDialog::replaceSelected()
{
	accept();
}

void ReplaceDialog::inputOldStr()
{
	LineEdit2->setFocus();
}

void ReplaceDialog::inputNewStr()
{
	PushButton1->setFocus();
}

void ReplaceDialog::setOldStr( QString str )
{
	old_str = str;
	if (( old_str ) && ( old_str.length() > 0 ))
		LineEdit1->setText( old_str );
	LineEdit1->selectAll();			// v3.5.0
}

void ReplaceDialog::setNewStr( QString str )
{
	new_str = str;
	if (( new_str ) && ( new_str.length() > 0 ))
		LineEdit2->setText( new_str );
}



/*
 *  Destroys the object and frees any allocated resources
 */
ReplaceDialog::~ReplaceDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

