
// ******************************************************************
// Copyright (c) 2003 Satoshi, All Rights Reserved.
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Author : Satoshi ( af230533@yahoo.co.jp )
// ******************************************************************

#ifndef TEXTEDIT_H
#define TEXTEDIT_H

#define QTEXTEDIT_OPEN_API

#include <qpe/filemanager.h>

#include <qmainwindow.h>
#include <qmultilineedit.h>
#include <qlist.h>
#include <qmap.h>

#include "filedialog.h"

class QWidgetStack;
class QToolButton;
class QPopupMenu;
class QToolBar;
class QLineEdit;
class QAction;
// class FileSelector;  delete!!!
class QpeEditor;
class QPEMenuBar;
class QComboBox;

#define		CODEC_NONE		0
#define		CODEC_UNICODE	0
#define		CODEC_UTF8		1
#define		CODEC_SJIS		2
#define		CODEC_EUCJP		3
#define		CODEC_JIS		4
#define		CODEC_EUCKR		5
#define		CODEC_GBK		6
#define		CODEC_ASC_SJIS	7		// always last number !!!

#define		CODEC_AUTO		0

// ------------------------------------- v1.2.1 lone number
#define		LINE_NUMBER_TITLE	1
#define		LINE_NUMBER_FRONT2	2
#define		LINE_NUMBER_FRONT3	3
#define		LINE_NUMBER_FRONT4	4

#define		DEFAULT_HMARGIN		3
//#define		LINE_DISP_SIZE		3		// ---> line_disp  v2.0.0
#define		LINE_DISP_SPACE		5		// pixel

// ------------------------------------- v1.2.1 check frame width
#define		AUTO_OR_NOWRAP		-99
#define		MIN_FRAME_WIDTH		200
#define		FIX_CELL_WIDTH		3

// ------------------------------------- v1.0.0  instead of QList
#define		MAX_LIST_COUNT		7

// ------------------------------------- v1.2.5  file type
#define		FILE_TEXT			0
#define		FILE_USER1			1
#define		FILE_USER2			2
#define		FILE_USER3			3
#define		FILE_USER4			4
#define		FILE_USER5			5
#define		FILE_ETC			6

// ------------------------------------- v1.2.6  reserved word length
#define		MAX_RESERVED_LENGTH	30
// ------------------------------------- v3.1.0  history of search words
#define		MAX_SEARCH_COUNT	10

// ------------------------------------- v1.3.1  max pos of vertical line
//												1200 --> 1400 v1.3.1a
#define		MAX_VLINE_PIX		1400

// ------------------------------------- v2.0.0  auto select words
#define		CHAR_1B_TAB				1
#define		CHAR_1B_SPACE			2
#define		CHAR_1B_NUM				11
#define		CHAR_1B_ALPHA_UPP		12
#define		CHAR_1B_ALPHA_LOW		13
#define		CHAR_1B_SYMBOL			21
#define		CHAR_1B_KANA			31
#define		CHAR_1B_OTHER			41

#define		CHAR_2B_NUM				101
#define		CHAR_2B_ALPHA_UPP		102
#define		CHAR_2B_ALPHA_LOW		103
#define		CHAR_2B_SYMBOL			201

#define		CHAR_2B_JP_SPACE		301
#define		CHAR_2B_JP_KATAKANA		401
#define		CHAR_2B_JP_SYMBOL		501
#define		CHAR_2B_JP_KANA			601
#define		CHAR_2B_JP_KANJI		602

// ------------------------------------- v2.1.0  idiom option
#define		MAX_IDIOM_COUNT			9

// ------------------------------------- v2.1.4  text & user color
#define		MAX_FILE_COLOR			7

// ------------------------------------- v2.2.0 option : special key
#define		SP_NONE					0
#define		SP_HALF_SPACE			1
#define		SP_AUTO_SELECT			2
#define		SP_REDO				    3
#define		SP_UNDO					4
#define		SP_DEL_LINE				5
#define		SP_DUP_LINE				6
#define		SP_FIND					7
#define		SP_FINDNEXT				8
#define		SP_REPLACE				9
#define		SP_DATETIME				10
#define		SP_IDIOM				11
#define		SP_FULLPATH				12
#define		SP_EDITFINDPREV			13
#define		SP_FINDPREV				14
#define		SP_SAVE					15
#define		SP_NAMESAVE				16
#define		SP_CONVERT				17		// v3.3.1

// ------------------------------------- v2.2.2 cr_code : append Macintosh CR
#define		CR_DEFAULT				0
#define		CR_WIN					1
#define		CR_MAC					2


class ListLastFile
{
public:
	QString		path( int i ) const	{ return p[i]; }
	int		col( int i ) const	{ return c[i]; }
	int		line( int i ) const	{ return l[i]; }
	int		color( int i ) const	{ return cnum[i]; }
	void		itemSet( int i, QString path, int col, int line, int color= 0 ) { p[i]= path; c[i]= col; l[i]= line; cnum[i]= color; }
	void	clear( int i ) 	{ c[i] = -1; }
	void	move_last( int i )
			{
				int		k;
				QString	path = p[i];	int	col = c[i];	int	line = l[i];	int	c_num = cnum[i];
				for( k= i ; k < MAX_LIST_COUNT - 1 ; k++ )
				{
					p[k] = p[k+1];
					c[k] = c[k+1];
					l[k] = l[k+1];
					cnum[k] = cnum[k+1];
				}
				p[k] = path;
				c[k] = col;
				l[k] = line;
				cnum[k] = c_num;
			}
private:
	QString		p[MAX_LIST_COUNT];
	int		c[MAX_LIST_COUNT];
	int		l[MAX_LIST_COUNT];
	int		cnum[MAX_LIST_COUNT];
};


// --------------------------------------------------- 2003.07.27 ʬץ

class UserFileInfo
{
public:
	bool		RegExpress;
	int			half_color;

	QString		Ext;
	QString		Word1;
	QString		Word2;
	QString		Word3;
	QString		Comment;
	int			Color1;
	int			Color2;
	int			Color3;
	int			CommentColor;
};

// --------------------------------------------------- v2.2.0 option : special key
class SpecialKey
{
public:
	int			ctrl_enter;
	int			ctrl_space;
	int			shift_enter;
	int			shift_space;
	int			fn_M;
	int			fn_N;
	int			fn_O;
	int			fn_P;
	int			fn_A;
	int			fn_S;
//	int			fn_space;
};

class TextEdit : public QMainWindow
{
	Q_OBJECT

public:
	TextEdit( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
	TextEdit( QString baseName, QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
	~TextEdit();

	void openThisFile(  const QString &f );
	void openFile( const QString & );
	uint  checkCodec( const char *buf );
	void updateCaption( const QString &name=QString::null );

	QString	arg0_baseName;			// v2.0.1
	void	wrap_this( void );
	QString getUserJumpU( void );
	QString getUserJumpJ( void );
	QString getLine1Text( void );
	QString getDateTime( void );
	bool	appendFileExtension;
	void	jump_to( int line );

public slots:
	void setDocument(const QString&);

protected:
	void closeEvent( QCloseEvent *e );

private slots:
	void qcop_receive( const QCString &msg, const QByteArray &data );

	void fileNew();
	void fileRevert();
	void fileOpen();
	void fileSave();
	void fileMenuSave();
	void fileMenuSaveAs();
	void fileMenuFiler();
	void fileClearHistory();
	void fileReadOnly(bool y);
	void openLastFile( int id );

	void reSetCursorPosition();
	void editCut();
	void editCopy();
	void editPaste();
	void editDuplicate();
	void editRemove();
	void editSelectAll();
	void editSelectTop();
	void editSelectBottom();
	void editSelectMark();
	void editFind();
	void editFindPrev();
	void editFindCommon();

	void findNext();
	void findPrev();
	void findClose();
	void replaceProc();
	void insertDateTime();		// v1.0.0
	void insertFullPath();		// v2.2.2
	void otherProcNum( int other_num );
	void undoProc();
	void redoProc();

	void search();
	void accept();

	void setFileType( QString ext );
	void newFile( const DocLnk & );
	void openFile( const DocLnk & );
	void showEditTools();

	void changeOverWrite();
	void selectWords();

	void jump_top();
	void jump_bottom();
	void jump_number();
	void MarkCursorPos( bool );
	void jump_markpos();
	void zoomIn();
	void zoomOut();
	void setBold(bool y);
	void setItalic(bool y);
	void setUpdateCellWidth( void );
	void setWordWrap( bool y );
	void setAutoIndent( bool y );
	void setShortCutKey(bool y);
	void setCursorLine(int l_num);
	void setTextColor( int t_num );
	void setBackColor(int c_num);
	void optionProcNum( int opt_num );
	void optionSpecialKey( bool which );
	void setSpecialKey( bool which, int sp_key, int slot_num );
	void inputHalfSpace();
	void optionProc();
	void optionProc2();
	void optionProc3();
	void optionProc4();
	void optionProc5();
	void idiomNumber1();
	void idiomNumber2();
	void idiomNumber3();
	void idiomNumber4();
	void idiomNumber5();
	void idiomNumber6();
	void idiomNumber7();
	void idiomNumber8();
	void idiomNumber9();
	void idiomNumber( int );

	void tabIndent();
	void shiftTabIndent();

	void idiomListBox();
	void show_clipboard();
	void countCharacter();
	void aboutMessage();

	void setDoingCodec();
	int  allRight();

	void timerOn();
	void convertWordProc();
	void convertAscii2Zen();
	void convertZen2Ascii();

private:
	void colorChanged( const QColor &c );
	bool save();
	void clear();
	void textisChanged();
	void setFontSize(int sz, bool round_down_not_up);
	void setLastFile();
	void writeConf();
	void writeConf2();

private:
	QWidgetStack	*editorStack;
	QpeEditor	*editor;
	QToolBar	*menu, *editBar, *searchBar;
//	QLineEdit	*searchEdit;	v3.1.0
	QComboBox	*searchComboEdit;					// v3.1.0
	QString		search_words[MAX_SEARCH_COUNT + 1];	// v3.1.0
	QString		family_name;						// v3.1.0

	DocLnk		*doc;
	bool 		searchVisible;
	bool 		bFromDocView;
	QAction		*zin, *zout;

	// ----------------------- append v0.9.0
	uint		fsize;
	QTextCodec	*codec;
	uint		codec_num;
	// ----------------------- append v0.9.2
	QString		file_ext;
	QString		last_file;
//	uint		last_col;
//	uint		last_line;
	// ----------------------- append v1.0.0
	QPEMenuBar *	menuBar;
	QPopupMenu *	popFile;
	QPopupMenu *	popEdit;
	QPopupMenu *	popView;
	QPopupMenu *	popSelect;
	QPopupMenu *	popOption;
	QPopupMenu *	popOther;
	QAction	*	jump_mark;
	int		mk_xx, mk_yy;
	// ---------------------- v3.3.1	convert word
	QPopupMenu *	popConvert;

	QTimer	*	timer;		// v2.0.3

	int		id_file;
	int		id_edit;
	int		id_view;
	int		backcolor;
	int		textcolor;
	int		windateform;
	int		tablength;
	int		input_codec;
	int		output_codec;
	int		cursor_color;
	int		cursor_line_color;
	int		cursor_style;
	int		cursor_draw;
	int		selected_color;
	int		vertical_line;
	int		scrollbar_disp;
	int		cr_code;
	int		c_sensitive;
	bool	incremental_s;
	bool	find_backword;		// v3.0.0
	int		cursorword;
	int		wrap_method;
	bool	word_wrap;
	bool	auto_indent;
	bool	separateKanaKanji;
	int		time_interval;		// minute
	QString	autosave_dir;		// v2.0.5
	bool	is_small;			// v2.0.3
	bool	ok_is_enter;		// v2.0.4
	int		ctrl_up;			// v2.0.8
	int		ctrl_down;			// v2.0.8
	bool	save_fast;			// v2.1.7
	bool	default_cutcopy;	// v2.2.1

	bool	mac_flg;			// 2.2.2
	bool	markpos_toggle;		// 2.3.2

	bool	history_clear;		// v3.5.0
	bool	read_only;			// v3.5.0

	// --------------------------  v2.2.0
	QAccel 		*sp_acc;

	UserFileInfo	user[MAX_FILE_COLOR];	// 0:text, 1:user1, 2:user2....
	QStringList		extUserlist[MAX_FILE_COLOR];
	SpecialKey		sp_key;


	// ---------------------------- v2.1.0 idiom
	QString		idiom[MAX_IDIOM_COUNT];

	bool		shortcutkey;
	bool		movecursor;
	bool		selectedcursor;
	int		line_number;
	bool		line_number_cr;
	int		cr_markdisp;
	bool		icon_new;
	bool		icon_open;
	bool		icon_save;
	bool		icon_cut;
	bool		icon_copy;
	bool		icon_paste;
	bool		icon_find;
	bool		icon_nfind;
	QString		icon_nw_name;
	QString		icon_op_name;
	QString		icon_sv_name;
	QString		icon_ct_name;
	QString		icon_cp_name;
	QString		icon_ps_name;
	QString		icon_fd_name;
	QString		icon_nf_name;

	QString		userJumpU;
	QString		userJumpJ;
	QString		userJumpMnt;		// v3.3.0
	QString		userJumpHome;		// v3.3.0
	QString		userJumpText;		// v3.3.0
	QString		userJumpUser;		// v3.3.0

	int		b_color;

	bool		isChanged;

//	QList<ListLastFile>	listF;	// v1.0.0  insert( index,.. ), take( index ) not correct!!!
	ListLastFile		listF;		// instead of QList
	bool			new_file;	// true : new
	QString			old_str;	// prev replace
	QString			new_str;	// prev replace
	QString			old_num;	// prev jump
};

#endif
